Stan Math Library: stan/math/prim/scal/err/out_of_range.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
out_of_range.hpp File Reference
`#include <stan/math/prim/scal/meta/error_index.hpp>`
`#include <typeinfo>`
`#include <string>`
`#include <sstream>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
void | stan::math::out_of_range (const char *function, const int max, const int index, const char *msg1="", const char *msg2="")
| Throw an out_of_range exception with a consistently formatted message. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.